SystemOrganization addCategory: #'SDTS-ISO8211Framework'!
SystemOrganization addCategory: #'SDTS-Browser'!

Model subclass: #SDTSTransferBrowser
	instanceVariableNames: 'modules modulesIndex modulesKeys currentlySelectedModulesKey tags tagsIndex currentlySelectedRecordNumber'
	classVariableNames: 'DataDirectory MasterDDDirectory'
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SDTSTransferBrowser commentStamp: '<historical>' prior: 0!
An SDTSTransfer is made up of modules. Each module is an ISO8211 Data Descriptive File consisting of a Data Descriptive Record and one or more Data Records.

An SDTSTransfer consists of a set of files on a file system. Each file constitutes an SDTS module.

See: The Spatial Data Transfer Standard - Handbook for Technical Staff!

!SDTSTransferBrowser class methodsFor: 'instance creation' stamp: 'jrm 9/7/2009 14:54'!
openMorphic
	"SDTSTransferBrowser openMorphic"

	 | model topView modulesView listFont dataView tagsView dataDefinitionView dataDisplayView |

	listFont := StrikeFont allInstances
		detect: [:f | (f name beginsWith: 'CourierFixed') and: [f height = 11]]
		ifNone: [TextStyle default fontAt: 1].

	model := self new.
	model modules: model sourceDirectory.

	topView := SystemWindow
		labelled: 'SDTS TRANSFER BROWSER'.
	topView model: model.

	 modulesView :=
		PluggableListMorph on: model
			list: #modulesKeys
			selected: #currentlySelectedModulesIndex
			changeSelected: #currentlySelectedModule:
			menu: #modulesMenu:.
		modulesView selection: 1.

	tagsView := PluggableListMorph on: model
		list: #tags 
		selected: #currentlySelectedTagsIndex
		changeSelected: #currentlySelectedTag:
		menu: #tagsMenu:.

	 dataDefinitionView:= PluggableTextMorph on: model
		text: #tagFormatAsString
		accept: #put:.
	modulesView selection: 0; font: listFont .

	dataView := PluggableTextMorph on: model
		text: #dataContents 
		accept: #put:
		readSelection: nil
		menu: #dataViewMenu:.
	modulesView selection: 0; font: listFont .

	dataDisplayView _ PluggableTextMorph on: model
		text: #dataDisplay
		accept: #put:
		readSelection: nil
		menu: #dataViewMenu:.
	modulesView selection: 0; font: listFont .

 	topView addMorph: modulesView frame: (0.0@0 corner: 0.15@0.25). 
   	topView addMorph: tagsView             frame: (0.15@0 corner: 0.25@0.25). 
   	topView addMorph: dataDefinitionView frame: (0.25@0 corner: 1.0@0.25).
   	topView addMorph: dataView frame: (0.0 @ 0.25 corner: 1.0@0.50).  
   	topView addMorph: dataDisplayView frame: (0.0@0.50 corner: 1.0@1.0).

	topView openInWorld

! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 11/7/2001 19:51'!
currentlySelectedModule: anInteger

	modulesIndex _ anInteger. 
	currentlySelectedRecordNumber _ 1.
	currentlySelectedModulesKey _ self modulesKeys at: modulesIndex. 
	self changed: #tags; changed: #directoryContents; changed:#tagFormatAsString; changed: #dataContents! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/7/2001 09:27'!
currentlySelectedModulesIndex

	^ modulesIndex! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/6/2001 20:21'!
currentlySelectedModulesKey

	^ currentlySelectedModulesKey! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 11/7/2001 19:33'!
currentlySelectedRecordNumber

	^ currentlySelectedRecordNumber! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 7/7/2001 12:36'!
currentlySelectedTag: anInteger

	tagsIndex _ anInteger.  
	self changed: #tagFormatAsString; changed: #dataContents! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/7/2001 10:07'!
currentlySelectedTagsIndex

	^ tagsIndex! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 11/7/2001 20:15'!
dataContents
	tagsIndex = 0 ifTrue: [ ^ String new ]. 
	currentlySelectedRecordNumber = 0 ifTrue: [ currentlySelectedRecordNumber _ currentlySelectedRecordNumber + 1].
	(self dataRecords size >= currentlySelectedRecordNumber) ifTrue: [
 ^ (self dataRecords at: currentlySelectedRecordNumber) dataTagged: (tags at: tagsIndex)] ifFalse: [  ^ (self dataRecords at: 1) dataTagged: (tags at: 3)]! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 12/8/2002 20:17'!
dataDisplay

^ 'This text needs to be provided'.! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 11/7/2001 19:54'!
dataRecords

^ (modules at: currentlySelectedModulesKey) dataRecords! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 11/7/2001 19:29'!
dataViewMenu: aMenu

	^ aMenu addList: #((next nextRecord)
		(previous previousRecord))! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 12/9/2002 00:42'!
datadescritiveRecords

^ (modules at: currentlySelectedModulesKey) dataDescriptiveRecord! !

!SDTSTransferBrowser methodsFor: 'initialization' stamp: 'jrm 9/6/2009 17:27'!
initialize


	modulesIndex _ 0.
	tagsIndex _ 0! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/17/1999 22:09'!
modules

	^ modules! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/17/1999 23:01'!
modules: aDictionary


modules _ aDictionary! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 9/6/2009 17:28'!
modulesKeys

	^ modules keys asSortedCollection! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 10/26/1999 20:02'!
modulesMenu: aMenu

	^ aMenu addList: #((dataDiscriptiverRecord ddCmd)
		(dataRecords drCmd)
		-
		(quit notYetImplemented))! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 11/7/2001 19:49'!
nextRecord
	"Get the next data record in the currently selected module"

currentlySelectedRecordNumber _ currentlySelectedRecordNumber + 1.
self changed: #dataContents! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 11/7/2001 19:41'!
perform: selector orSendTo: otherTarget
	"Selector was just chosen from a menu by a user.  If can respond, then perform it on myself.  If not, send it to otherTarget, presumably the editPane from which the menu was invoked." 

	(self respondsTo: selector) ifTrue: [self perform: selector] ifFalse: [otherTarget perform: selector]
! !

!SDTSTransferBrowser methodsFor: 'menues' stamp: 'jrm 11/7/2001 20:10'!
previousRecord
	"Get the next data record in the currently selected module"

currentlySelectedRecordNumber _ currentlySelectedRecordNumber  -1.
self changed: #dataContents! !

!SDTSTransferBrowser methodsFor: 'initialization' stamp: 'jrm 9/7/2009 14:37'!
sourceDirectory
	" A transfer is contained in a directory on a file system"
	"SDTSTransferBrowser  sourceDirectory"
	| aFileDirectory eachName modulesDict |
	modulesDict _  Dictionary new.

     aFileDirectory _ PluggableFileList getFolderDialog open.

" Download the file http://edcftp.cr.usgs.gov/pub/data/DLG/2M/AZ/AZ.bound.sdts.tar.gz and put the extracted files into a directory of their own. SDTS transfer files should be stored individual directories because of potential name space collision"

"Hard code a directory name for development and debug purposes
	aFileDirectory _ FileDirectory on: '/Developer/Squeak Development/SDTS Transfers/Arizona'.  "
	
	aFileDirectory entries do: [ :each |  ((eachName _ each name) endsWith: '.DDF') ifTrue:[
modulesDict at: (eachName copyUpTo: $.) put: (SDTSModule newFrom: aFileDirectory pathName , aFileDirectory pathNameDelimiter asString ,eachName)]].
	^  modulesDict
! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/7/2001 11:59'!
tagFormatAsString
tagsIndex = 0 ifTrue: [ ^ String new ].
 ^ ((modules at: currentlySelectedModulesKey) dataDescriptiveRecord) dataTagged: (tags at: tagsIndex)! !

!SDTSTransferBrowser methodsFor: 'access' stamp: 'jrm 7/7/2001 12:06'!
tags

modulesIndex = 0 ifFalse:
 [tagsIndex _ 1. ^ tags _ (modules at:   currentlySelectedModulesKey) tags ] ifTrue: [^ Array new]! !

Dictionary subclass: #RecordMap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!RecordMap commentStamp: '<historical>' prior: 0!
A RecordMap is a dictionary of field maps that is used to help populate object instance variables with  data that is contained in a record. 
!

!RecordMap methodsFor: 'ISO8211DDR' stamp: 'jrm 6/10/2001 21:48'!
fields
	"What are the names of the fields that this record maps"


 	^ self keys! !

!RecordMap methodsFor: 'accessing' stamp: 'jrm 3/7/2001 21:58'!
formatOf: aField

	^(self at: aField ) format! !

!RecordMap methodsFor: 'accessing' stamp: 'jrm 11/6/2001 21:46'!
intervalFor: aString
	"aString contains the name of the field"

(self offsetOf: aString) to: (self lengthOf: aString)	! !

!RecordMap methodsFor: 'accessing' stamp: 'jrm 3/7/2001 21:59'!
lengthOf: aField 

	^(self at: aField ) length! !

!RecordMap methodsFor: 'accessing' stamp: 'jrm 3/7/2001 22:09'!
objectToBeOf: aField    

	^(self at: aField ) objectToBe! !

!RecordMap methodsFor: 'accessing' stamp: 'jrm 3/7/2001 21:59'!
offsetOf: aField    

	^(self at: aField ) offset! !

Object subclass: #FieldMap
	instanceVariableNames: 'format objectToBe'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!FieldMap commentStamp: '<historical>' prior: 0!
FieldMap is the abstract class for FixedFieldMap and VariableFieldMap. Instances of which are used to map data from external files into objects. They are used in conjunction with a RecordMap to objectify external data i.e. create objects with instance variable values set to the values of fields in external records

Structure:

format     contains a description of the data . A=ascii, B=bigendian binary, b=littleendian, I=integer.
objectToBe  contains the name of the class that we want to create using the data.


!

FieldMap subclass: #DelimitedFieldMap
	instanceVariableNames: 'delimeter position'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!DelimitedFieldMap commentStamp: '<historical>' prior: 0!
A DelimitedFieldMap is a FieldMap which uses a delimiter to identify the end of the field. 

Possible useful expressions for doIt or printIt.

Structure:
 delimiter		a delimiter is any character that is used to mark then end of a string.

Any further useful comments about the general approach of this implementation.!

!DelimitedFieldMap methodsFor: 'access' stamp: 'jrm 3/28/2001 22:54'!
objectFromRecord: aByteArray

^ (aByteArray copyFrom: (offset + 1) to: (offset + length)) asString perform: objectToBe

! !

!FieldMap class methodsFor: 'instance creation' stamp: 'jrm 3/3/2001 14:23'!
new

	^ super new! !

!FieldMap methodsFor: 'access' stamp: 'jrm 3/3/2001 12:54'!
format

 ^ format ! !

!FieldMap methodsFor: 'access' stamp: 'jrm 3/1/2001 22:05'!
objectToBe

 ^ objectToBe! !

FieldMap subclass: #FixedFieldMap
	instanceVariableNames: 'offset length'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!FixedFieldMap commentStamp: '<historical>' prior: 0!
A FixedFieldMap is used to extract data based on offset and length

Structure:
length      contains the integer length of the field.
offset       contains an interger identifying the offset value of the field.
!

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 7/13/2001 19:49'!
format: aCharacter length: anInteger objectToBe: aSymbol

	"Create a fieldMap that can be used to objectify external data"

^ self format: aCharacter length: anInteger offset: 0 objectToBe: aSymbol
! !

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 3/3/2001 12:59'!
format: aCharacter length: anInteger offset: anotherInteger objectToBe: aSymbol

	"Create a fieldMap that can be used to objectify external data"

	format _ aCharacter.
	length	_ anInteger. 
	offset 	_ anotherInteger.
	objectToBe _ aSymbol.
^ self! !

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 3/1/2001 22:04'!
length
	
 ^ length! !

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 7/15/2001 21:18'!
length: anInteger
	
 ^ length _ anInteger! !

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 3/8/2001 21:06'!
objectAt: aString

^ (aString copyFrom: (offset + 1) to: (offset + length)) perform: objectToBe

! !

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 7/15/2001 21:35'!
objectFromRecord: aByteArray

^ (aByteArray copyFrom: (offset + 1) to: (offset + length))  perform: objectToBe

! !

!FixedFieldMap methodsFor: 'access' stamp: 'jrm 3/1/2001 22:07'!
offset
	

 ^ offset ! !

Object subclass: #FieldSpecification
	instanceVariableNames: 'name subfields'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!FieldSpecification methodsFor: 'as yet unclassified' stamp: 'jrm 6/15/2003 21:02'!
initialize

	subfields _ Dictionary new.! !

Object subclass: #ISO8211LeaderMap
	instanceVariableNames: ''
	classVariableNames: 'LeaderMap'
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211LeaderMap commentStamp: '<historical>' prior: 0!
An ISO8211Leader is a 24 byte string that is used to map into the ISO8211Directory. There is just one leader layout defined for all module records in the transfer. The data descriptive record and the data record use the same leader.

!

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:43'!
appIndicator

^ LeaderMap at: #appIndicator! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:44'!
baseAddress

^ LeaderMap at: #baseAddress! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:45'!
characterSet

^ LeaderMap at:  #characterSet! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:45'!
directoryLengthLength

^ LeaderMap at:  #directoryLengthLength! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:45'!
directoryOffsetLength

^ LeaderMap at:  #directoryOffsetLength! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:46'!
directoryTagLength

^ LeaderMap at:  #directoryTagLength! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:44'!
fieldControlLength

^ LeaderMap at: #fieldControlLength! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:43'!
iceIndicator

^ LeaderMap at: #iceIndicator! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:42'!
identifier

^ LeaderMap at: #identifier! !

!ISO8211LeaderMap class methodsFor: 'initialize-release' stamp: 'jrm 6/10/2001 22:30'!
initialize

	"ISO8211Leader initialize"
	LeaderMap _ Dictionary new.
LeaderMap at: #length put: ((FixedFieldMap new)format: #I length: 5 offset: 0 objectToBe: #asNumber).
LeaderMap at: #level put: ((FixedFieldMap new)format: #I length: 1 offset: 5 objectToBe: #asString).
LeaderMap at: #identifier put: ((FixedFieldMap new)format: #I length: 1 offset: 6 objectToBe: #asString).
LeaderMap at: #iceIndicator put: ((FixedFieldMap new)format: #I length: 1 offset: 7 objectToBe: #asString).
LeaderMap at: #appIndicator put: ((FixedFieldMap new)format: #I length: 2 offset: 8 objectToBe: #asString).
LeaderMap at: #fieldControlLength put: ((FixedFieldMap new)format: #I length: 2 offset:  10 objectToBe: #asNumber).
LeaderMap at: #baseAddress put: ((FixedFieldMap new)format: #I length: 5 offset: 12 objectToBe: #asNumber).
LeaderMap at: #characterSet put: ((FixedFieldMap new)format: #I length: 3 offset: 17 objectToBe: #asString).
LeaderMap at: #directoryLengthLength put: ((FixedFieldMap new)format: #i length: 1 offset: 20 objectToBe: #asNumber).
LeaderMap at: #directoryOffsetLength put: ((FixedFieldMap new)format: #I length: 1 offset: 21 objectToBe: #asNumber).
LeaderMap at: #directoryTagLength put: ((FixedFieldMap new)format: #I length: 1 offset: 23 objectToBe: #asNumber).! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/3/2001 20:06'!
length

^ LeaderMap at: #length! !

!ISO8211LeaderMap class methodsFor: 'constants' stamp: 'jrm 3/4/2001 01:06'!
level

^ LeaderMap at: #level! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:57'!
appIndicator

	^ ISO8211LeaderMap objectAt: #appIndicator! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
baseAddress

	^ ISO8211LeaderMap objectAt: #baseAddress! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
characterSet

	^ ISO8211LeaderMap objectAt: #characterSet! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 4/2/2001 00:33'!
directoryEntrySize

	^ self directoryTagLength + self directoryLengthLength + self directoryOffsetLength ! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
directoryLengthLength

	^ ISO8211LeaderMap objectAt: #directoryLengthLength! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
directoryOffsetLength

	^ ISO8211LeaderMap objectAt: #directoryOffsetLength! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
directoryTagLength

	^ ISO8211LeaderMap objectAt: #directoryTagLength! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:57'!
fieldControlLength

	^ ISO8211LeaderMap objectAt: #fieldControlLength! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:57'!
iceIndicator

	^ ISO8211LeaderMap objectAt: #iceIndicator! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:57'!
identifier

	^ ISO8211LeaderMap objectAt: #identifier! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
length


	^ ISO8211LeaderMap objectAt: #length! !

!ISO8211LeaderMap methodsFor: 'accessing' stamp: 'jrm 11/15/2001 17:58'!
level

	^ ISO8211LeaderMap objectAt: #level! !

Object subclass: #ISO8211Record
	instanceVariableNames: 'leader directory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211Record commentStamp: '<historical>' prior: 0!
This class is the abstract class for the ISO8211DataRecord and the ISO8211DataDescriptiveRecord classes. ISO8211Records are contained in ISO8211Modules so each individual record in a transfer module is adressabel via its offset. The length of the record is defined in its first five characters which
are ASCII integer values. This class is an abstract class.!

ISO8211Record subclass: #ISO8211DataDescriptiveRecord
	instanceVariableNames: 'dataDescriptiveArea'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211DataDescriptiveRecord commentStamp: '<historical>' prior: 0!
Each SDTSModule has one DDR. The DDR starts at postion 25 (offset 24). The
first part of the DDR is the directory. The directory consists of a variable number of entries for each possible record in the file. A directory entry consists of a string of integers, the length of which is defined in the header. There are three fields. The tag field is used as an internal reference key; its length is defined by the directoryTagLength of the IS08211Leader. The offset field is the offset to where the data associated with the tag is located. The length field is the length of the data associated with the tag.s!

!ISO8211DataDescriptiveRecord methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:39'!
dataDescriptiveArea:  anISO8211DataDescriptiveArea
	dataDescriptiveArea _ anISO8211DataDescriptiveArea! !

!ISO8211DataDescriptiveRecord methodsFor: 'accessing' stamp: 'jrm 1/25/2003 21:42'!
dataTagged: aString

	^ (directory dataMap at: aString) objectFromRecord: (dataDescriptiveArea byteArray). ! !

!ISO8211DataDescriptiveRecord methodsFor: 'accessing' stamp: 'jrm 7/8/2001 17:44'!
formats
	self halt.! !

!ISO8211DataDescriptiveRecord methodsFor: 'accessing' stamp: 'jrm 7/8/2001 17:44'!
lables
	self halt.! !

!ISO8211DataDescriptiveRecord methodsFor: 'accessing' stamp: 'jrm 12/14/2002 19:56'!
recordMapFor: aString

	| recordMap temp |
	
	recordMap _ RecordMap new.
	temp _ self dataTagged: aString.

self halt.
	
! !

!ISO8211DataDescriptiveRecord methodsFor: 'accessing' stamp: 'jrm 11/16/2001 19:53'!
tags
	^ directory tags! !

ISO8211Record subclass: #ISO8211DataRecord
	instanceVariableNames: 'userDataArea'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211DataRecord class methodsFor: 'instance creation' stamp: 'jrm 11/18/2001 11:41'!
userDataArea: anISO8211UserDataArea
	^ (self new) userDataArea: anISO8211UserDataArea! !

!ISO8211DataRecord methodsFor: 'accessing' stamp: 'jrm 11/17/2001 19:11'!
dataTagged: aString

	aString = '0000' ifTrue: [ ^ 'Error: There is no data record for tag 0000'].
	^ (directory dataMap at: aString) objectFromRecord: (userDataArea byteArray). ! !

!ISO8211DataRecord methodsFor: 'accessing' stamp: 'jrm 11/18/2001 12:26'!
datalength
	^ userDataArea size! !

!ISO8211DataRecord methodsFor: 'accessing' stamp: 'jrm 6/20/2003 23:13'!
getDataFor: aString
| anInterval aPath fieldMap aByteArray |

" This method is specific to the module type LE field type SADR"
fieldMap _ self directory dataMap at: aString.
anInterval _ fieldMap offset + 1 to: ( fieldMap offset + fieldMap length -1) by: 8.
aByteArray _ self userDataArea byteArray. 
aPath _ LinearFit new.
 ( anInterval) do: [:each | aPath add:  (aByteArray longAt: each  bigEndian: true) @ (aByteArray longAt: (each + 4)  bigEndian: true )].
^ aPath! !

!ISO8211DataRecord methodsFor: 'accessing' stamp: 'jrm 6/20/2003 17:34'!
userDataArea
	
	^ userDataArea! !

!ISO8211DataRecord methodsFor: 'accessing' stamp: 'jrm 11/17/2001 20:24'!
userDataArea: anISO8211UserDataArea
	 userDataArea _ anISO8211UserDataArea! !

!ISO8211Record class methodsFor: 'instance creation' stamp: 'jrm 11/16/2001 22:26'!
leader: anIS08211Leader
 ^  (self new) initialize; leader: anIS08211Leader! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:06'!
baseAddress
	^ leader baseAddress! !

!ISO8211Record methodsFor: 'private' stamp: 'jrm 11/16/2001 20:19'!
buildDataMap
	
	^ directory tagLength: leader tagLength  tagLengthLength: leader tagLengthLength   tagOffsetLength: leader tagOffsetLength! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/18/2001 12:31'!
dataLength
	^ leader dataLength ! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/16/2001 19:26'!
directory
	^ directory ! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/18/2001 10:38'!
directory: anIS08211Directory
	  directory _ anIS08211Directory! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/17/2001 17:21'!
directoryFrom:  aByteArray  using: aDictionary
	^ directory _ ISO8211Directory directoryFrom:  aByteArray using: aDictionary! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:24'!
directoryLength
	^ leader baseAddress - 24! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/16/2001 18:09'!
identifier
	^ leader identifier! !

!ISO8211Record methodsFor: 'initialize-release' stamp: 'jrm 11/16/2001 22:26'!
initialize

	cache _ Dictionary new
	! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:56'!
leader
	^ leader ! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:56'!
leader:  anISO8211Leader

	 leader _  anISO8211Leader! !

!ISO8211Record methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:05'!
length
	^ leader length! !

Object subclass: #ISO8211RecordComponent
	instanceVariableNames: 'byteArray cache'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211RecordComponent commentStamp: '<historical>' prior: 0!
There are three components to an ISO8211Record. The leader and directory, also called the header, and the data. Each component consists of a byteArray and a cache for storing already converted items.

!

ISO8211RecordComponent subclass: #ISO8211Data
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

ISO8211RecordComponent subclass: #ISO8211DataDescriptiveArea
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

ISO8211RecordComponent subclass: #ISO8211Directory
	instanceVariableNames: 'dataMap'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211Directory class methodsFor: 'as yet unclassified' stamp: 'jrm 11/17/2001 18:34'!
directoryFrom: aString using: aDictionary
| entrySize directorySize numberOfEntries directoryStream directory |
directory _ self byteArray: aString asByteArray. 
directorySize _ aString size.
entrySize _ aDictionary inject: 0 into: [ :directoryEntySize :each | directoryEntySize _ directoryEntySize + each].
numberOfEntries _ directorySize / entrySize.
directoryStream _ ReadStream on: aString from: 1 to: directorySize.
(1 to: numberOfEntries) do: [:each | directory buildFieldMapFrom: (directoryStream next: entrySize) using: aDictionary].
^ directory! !

!ISO8211Directory methodsFor: 'private' stamp: 'jrm 11/16/2001 20:09'!
buildDataMap
	
| directoryString numberOfDirectoryEntries  directoryEntrySize directoryStream | 
" get directory. use directory to build record map"
	directoryString _ self directory.

	directoryEntrySize _ self directoryEntrySize.
	numberOfDirectoryEntries _ (directoryString size) / directoryEntrySize.
directoryStream _ ReadStream on: directoryString from: 1 to: directoryString size.
	(1 to: numberOfDirectoryEntries) do: [ :each | self buildFieldMapUsing: (directoryStream next: directoryEntrySize)] .! !

!ISO8211Directory methodsFor: 'private' stamp: 'jrm 11/17/2001 17:46'!
buildFieldMapFrom: aString using: aDictionary

	| dtl dll |
	dtl _ aDictionary at: #tagLength.
	dll _ aDictionary at: #lengthLength. 
 	^ dataMap at: ((aString copyFrom: 1 to:  dtl) )  put: ((FixedFieldMap new) format: #A length: ((aString copyFrom: (dtl +1) to: (dtl +dll))  asNumber) offset: ((aString copyFrom: (dtl +dll +1) to: aString size) asNumber) objectToBe: #asByteArray). ! !

!ISO8211Directory methodsFor: 'accessing' stamp: 'jrm 11/16/2001 22:31'!
dataMap
	^ dataMap! !

!ISO8211Directory methodsFor: 'initialize' stamp: 'jrm 11/17/2001 18:17'!
initialize

	dataMap _ RecordMap new.! !

!ISO8211Directory methodsFor: 'private' stamp: 'jrm 11/16/2001 22:32'!
length
	^ byteArray size! !

!ISO8211Directory methodsFor: 'private' stamp: 'jrm 11/16/2001 21:54'!
tagLength: directoryTagLength  LengthLength: directoryLengthLength   directoryOffsetLength: directoryOffsetLength


	 | aString tag length offset aFixedFieldMap |
aString _ byteArray asString.
	tag _ aString from: 1 to: directoryTagLength.
	length _ aString from: directoryTagLength + 1 to: directoryTagLength + directoryLengthLength.
	offset _ aString last: directoryOffsetLength.
	aFixedFieldMap _ FixedFieldMap format: #A length: length offset: offset objectToBe: #asByteArray.
	^ dataMap at: tag put: aFixedFieldMap! !

!ISO8211Directory methodsFor: 'accessing' stamp: 'jrm 11/17/2001 18:42'!
tags

	^ dataMap keys asArray ! !

ISO8211RecordComponent subclass: #ISO8211Leader
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

!ISO8211Leader commentStamp: '<historical>' prior: 0!
This class is the abstract class for the ISO8211DataRecord and the ISO8211DataDescriptiveRecord classes. ISO8211Leaders are contained in ISO8211Modules so each individual record in a transfer module is adressabel via its offset. The length of the record is defined in its first five characters which
are ASCII integer values. This class is an abstract class.!

!ISO8211Leader class methodsFor: 'instance creation' stamp: 'jrm 3/30/2001 17:56'!
new

	^ super new initialize! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:49'!
appIndicator
	
	^ cache at: #appIndicator ifAbsentPut: [ISO8211LeaderMap appIndicator objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:00'!
baseAddress
	
		^ cache at: #baseAddress ifAbsentPut: [ISO8211LeaderMap baseAddress objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/1/2001 13:42'!
baseAddress: aNumber
	
		^ cache at: #baseAddress ifAbsentPut: [aNumber]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/6/2001 21:55'!
buildFieldMapUsing: aString

	| dtl dll |
	dtl _ self directoryTagLength.
	dll _ self directoryLengthLength. 
 	^ recordMap at: ((aString copyFrom: 1 to:  dtl) )  put: ((FixedFieldMap new) format: #A length: ((aString copyFrom: (dtl +1) to: (dtl +dll))  asNumber) offset: ((aString copyFrom: (dtl +dll +1) to: aString size) asNumber) objectToBe: #asByteArray). ! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 4/4/2001 21:40'!
buildRecordMap
	
| directoryString numberOfDirectoryEntries  directoryEntrySize directoryStream | 
" get directory. use directory to build record map"
	directoryString _ self directory.

	directoryEntrySize _ self directoryEntrySize.
	numberOfDirectoryEntries _ (directoryString size) / directoryEntrySize.
directoryStream _ ReadStream on: directoryString from: 1 to: directoryString size.
	(1 to: numberOfDirectoryEntries) do: [ :each | self buildFieldMapUsing: (directoryStream next: directoryEntrySize)] .! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/8/2001 17:36'!
byteArray

	 ^ byteArray! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 4/1/2001 19:02'!
byteArray: aByteArray

	 byteArray _ aByteArray.
	^ self! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:50'!
characterSet
	
		^ cache at: #characterSet ifAbsentPut: [ISO8211LeaderMap characterSet objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/15/2001 22:11'!
data
	" drop the leader and the directory and return data only" 
	^ byteArray copyFrom: self baseAddress +1 to: byteArray size! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/18/2001 12:32'!
dataLength
	
	^ cache at: #length ifAbsentPut: [self length - self baseAddress ]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/8/2001 18:10'!
dataTagged: aString

	^ (recordMap at: aString) objectFromRecord: (self data)! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 4/2/2001 00:36'!
directory

^ (byteArray copyFrom: 25 to: self baseAddress -1) asString! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 4/2/2001 00:36'!
directoryEntrySize

	^ self directoryTagLength + self directoryLengthLength + self directoryOffsetLength ! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:44'!
directoryLayout
	
	^ cache at: #layout ifAbsentPut: [Dictionary  new at: #tagLength put:  self directoryTagLength ; at: #lengthLength put: self directoryLengthLength; at: #offsetLength put: self directoryOffsetLength; yourself]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:48'!
directoryLengthLength
	
		^ cache at: #directoryLengthLength ifAbsentPut: [ISO8211LeaderMap directoryLengthLength objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:50'!
directoryOffsetLength
	
	^ cache at: #directoryOffsetLength ifAbsentPut: [ISO8211LeaderMap directoryOffsetLength objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:47'!
directoryTagLength
	
	^ cache at: #directoryTagLength ifAbsentPut: [ISO8211LeaderMap directoryTagLength objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:50'!
fieldControlLength
	
	^ cache at: #fieldControlLength ifAbsentPut: [ISO8211LeaderMap directoryLengthLength objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 4/1/2001 15:10'!
fieldMap

self halt.! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/9/2001 21:20'!
getDataFor: aString 
	| anInterval aPath |
	"aString contains the name of the field"
anInterval _ ((self baseAddress) + 1 + (self recordMap at: aString) offset) to: ((((( self recordMap at: (aString)) length) asNumber) + self baseAddress + (self recordMap at: aString) offset) -1) by: 8 .  
aPath _ LinearFit new.
 ( anInterval) do: [:each | aPath add:  (self byteArray longAt: each  bigEndian: true) @ (self byteArray longAt: (each + 4)  bigEndian: true )].
^ aPath! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/6/2001 21:43'!
ggetDataFor: aString 
	| anInterval |
	"aString contains the name of the field"
anInterval _ recordMap intervalFor: aString.

^ ( anInterval) do: [:each | Transcript cr; show: each;  show: '   '; show: (self data unsignedLongAt: each bigEndian: true)] ! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:51'!
iceIndicator
	

	^ cache at: #iceIndicator ifAbsentPut: [ISO8211LeaderMap iceIndicator objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/16/2001 18:18'!
identifier
	
	^ cache at: #identifier ifAbsentPut: [ISO8211LeaderMap identifier objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/1/2001 16:23'!
identifier: aString
	
	^ cache at: #identifier ifAbsentPut: [aString]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/14/2001 19:26'!
leader: aLeader
	
	leader _ aLeader! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/15/2001 19:04'!
length
	
	^ cache at: #length ifAbsentPut: [ISO8211LeaderMap length objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 11/17/2001 16:51'!
level
	
	^ cache at: #level ifAbsentPut: [ISO8211LeaderMap level objectFromRecord: byteArray]! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/1/2001 13:36'!
recordMap

   ^ recordMap! !

!ISO8211Leader methodsFor: 'accessing' stamp: 'jrm 7/7/2001 10:30'!
recordMap: aRecordMap

  ^ recordMap _ aRecordMap! !

!ISO8211RecordComponent class methodsFor: 'instance creation' stamp: 'jrm 11/18/2001 11:33'!
byteArray: aString
	
	^ (self new initialize) byteArray: (aString asByteArray)! !

!ISO8211RecordComponent methodsFor: 'accessing' stamp: 'jrm 11/15/2001 18:31'!
byteArray
	^ byteArray  ! !

!ISO8211RecordComponent methodsFor: 'accessing' stamp: 'jrm 11/18/2001 11:38'!
byteArray: aByteArray

	 byteArray _ aByteArray! !

!ISO8211RecordComponent methodsFor: 'initialize' stamp: 'jrm 11/15/2001 18:25'!
initialize
	cache _ Dictionary new.
 	byteArray _ ByteArray new.! !

ISO8211RecordComponent subclass: #ISO8211UserDataArea
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-ISO8211Framework'!

Object subclass: #ModuleSpecification
	instanceVariableNames: 'fieldSpecifications'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

Object subclass: #SDTSModule
	instanceVariableNames: 'dataDescriptiveRecord dataRecords droppedLeader droppedDirectory droppedLeaderRecordNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SDTSModule commentStamp: '<historical>' prior: 0!
An SDTSTransfer is made up of modules. Each module is an ISO8211 Data Descriptive File consisting of a Data Descriptive Record and one or more Data Records.!

SDTSModule subclass: #SDTSLine
	instanceVariableNames: 'primaryField attribute endNode startNode polygonLeft polygonRight spatialAddress'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SDTSLine commentStamp: '<historical>' prior: 0!
A Line is a spatial object in the SDTS. It defines a one dimensional non-arc line object. A common name this line is a complete chain. The Line module is used to transfer complete chains for a particular 2-D manifold.

^Attribute ID
^Polygon ID Left
^Polygon ID Right
^Start Node ID
^End Node ID
-Spatial Address X component The easting value of each of the

!

!SDTSLine methodsFor: 'display' stamp: 'jrm 6/21/2003 16:19'!
displayTest

self displayOn: Display transformation: (WindowingTransformation window: (( Rectangle origin: self computeBoundingBox corner corner: self computeBoundingBox origin ) flipBy: #vertical centerAt: self computeBoundingBox center) viewport: (Rectangle extent: 600@700)) clippingBox: Display boundingBox rule: Form over fillColor: nil. 
 ! !

!SDTSLine methodsFor: 'accessing' stamp: 'jrm 3/28/2003 16:03'!
getDataFor: aString
| anInterval aPath |
anInterval _ ((self baseAddress) + 1 + (self recordMap at: aString) offset) to: ((((( self recordMap at: (aString)) length) asNumber) + self baseAddress + (self recordMap at: aString) offset) -1) by: 8 .  
aPath _ LinearFit new.
 ( anInterval) do: [:each | aPath add:  (self byteArray longAt: each  bigEndian: true) @ (self byteArray longAt: (each + 4)  bigEndian: true )].
^ aPath! !

!SDTSModule class methodsFor: 'instance creation' stamp: 'jrm 7/1/2001 10:55'!
newFrom: aFileName

	"Create a new instance "
"SDTSModule newFrom:'c:\Program Files\Squeak\stap\stapcatd.DDF'"

^ super new populateRecordsFrom: aFileName
! !

!SDTSModule methodsFor: 'access' stamp: 'jrm 3/28/2001 23:08'!
dataDescriptiveRecord

	^ dataDescriptiveRecord! !

!SDTSModule methodsFor: 'access' stamp: 'jrm 3/30/2001 16:45'!
dataRecords

	^ dataRecords! !

!SDTSModule methodsFor: 'access' stamp: 'jrm 6/23/2003 16:24'!
getDataFor: aString
	| aCollection |
	"aString is the name of a tag in the module. Get all of the data identified by that tag"

	aCollection _ GraphicSymbol new.
	 self dataRecords from: 1 to: self dataRecords size do: [:each | aCollection add: (each getDataFor: aString)].
	^ aCollection! !

!SDTSModule methodsFor: 'access' stamp: 'jrm 11/18/2001 12:33'!
populateRecords: aModule 
	| dataRecord currentIdentifier |
	dataDescriptiveRecord _ ISO8211DataDescriptiveRecord  leader: (ISO8211Leader byteArray: (aModule next: 24)).
	dataDescriptiveRecord directoryFrom: (aModule next:  dataDescriptiveRecord directoryLength) using: dataDescriptiveRecord leader directoryLayout.
	dataDescriptiveRecord dataDescriptiveArea: (ISO8211DataDescriptiveArea byteArray: (aModule next: 	dataDescriptiveRecord dataLength)).

	dataRecords _ OrderedCollection new.
	currentIdentifier _ 'D'. "The identifier in the first record must be D"
	droppedLeaderRecordNumber _ 0.
	[aModule atEnd]
		whileFalse: 
			[currentIdentifier = 'R'
				ifTrue: [dataRecord _ ISO8211DataRecord  userDataArea: (ISO8211UserDataArea byteArray: (aModule next: droppedLeader dataLength)). dataRecord directory: droppedDirectory copy
			 ]
				ifFalse: 
					[droppedLeaderRecordNumber _  droppedLeaderRecordNumber + 1.
					dataRecord _ ISO8211DataRecord  leader: (ISO8211Leader byteArray: (aModule next: 24)).
					dataRecord directoryFrom: (aModule next: dataRecord baseAddress - 24) using: dataRecord leader directoryLayout.
					dataRecord userDataArea: (ISO8211UserDataArea byteArray: (aModule next: dataRecord dataLength))
					].
			dataRecords add: dataRecord.
			droppedLeader = nil ifTrue:[
			dataRecords last identifier = 'R' ifTrue: [currentIdentifier _ 'R'. droppedLeader _ dataRecords last leader. droppedDirectory _ dataRecords last directory]]]! !

!SDTSModule methodsFor: 'access' stamp: 'jrm 7/1/2001 16:00'!
populateRecordsFrom: aFileName
 
|  aStream | 
"SDTSModule new populateRecordsFrom: 'c:\program files\squeak\stap\stapcatd.ddf'"
( aStream := StandardFileStream fileNamed: aFileName)
	openExecute:
		[self populateRecords:  aStream]! !

!SDTSModule methodsFor: 'access' stamp: 'jrm 7/6/2001 20:23'!
tags
 
^ dataDescriptiveRecord tags
! !

Object subclass: #SDTSModuleDecoder
	instanceVariableNames: 'recordDecoder records'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SDTSModuleDecoder commentStamp: '<historical>' prior: 0!
An SDTSModuleDecoder should be invoked to return a collection of completely instantiated objects. An SDTSRecordDecoder should be invoked to return an instance of a completely instantiated object."!

!SDTSModuleDecoder class methodsFor: 'as yet unclassified' stamp: 'jrm 4/9/2003 20:10'!
initialize
	"This is where we define the relationship between the raw data provided by a module and the useful objects that we want to create. A module decoder should be invoked to return a collection of completely instantiated objects. An SDTSRecordDecoder should be invoked to return an instance of a completely instantiated object."

! !

Object subclass: #SDTSRecordDecoder
	instanceVariableNames: 'fieldControl name lables formats objectRepresentationCode'
	classVariableNames: 'FieldObjectificationMap ModuleObjectificationMap'
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SDTSRecordDecoder commentStamp: '<historical>' prior: 0!
An instance of this class is used to decode individual records from an SDTSModule.

Possible useful expressions for doIt or printIt.

Structure:
fieldControl 	Defined by ISO8211 to describe the type of field
name 		The name of the field
recordMap	An ISO8211 field descriptor


If you don't understand this, don't worry. Just keep reading the documentation. (If you can find it;)!

!SDTSRecordDecoder class methodsFor: 'as yet unclassified' stamp: 'jrm 12/17/2002 10:14'!
initialize

	ModuleObjectificationMap _ Dictionary new.

	FieldObjectificationMap _ Dictionary new.
	
	FieldObjectificationMap at: 'LE' put: ' startNode: snid endNode: enid polygonLeft: pidl polygonRight: pidr points: sadr'. ! !

!SDTSRecordDecoder class methodsFor: 'as yet unclassified' stamp: 'jrm 7/8/2001 18:27'!
newOn: aString
	"Create the object that knows how to decode the data portion of an ISO8211DataRecord"

	^ super new on: aString! !

!SDTSRecordDecoder methodsFor: 'as yet unclassified' stamp: 'jrm 7/16/2001 20:40'!
decode: aByteArray
	"aString is a string of data from an ISO8211 data record"
self halt.
 ^ (recordMap at: 'Y' ) objectFromRecord: aByteArray! !

!SDTSRecordDecoder methodsFor: 'as yet unclassified' stamp: 'jrm 12/14/2002 23:22'!
on: aByteArray

| parseStream  |
parseStream _ ReadStream on: aByteArray asString.
fieldControl _ parseStream next: 4.
parseStream skip: 2.
name _ parseStream upTo: (Character value: 31).  
lables _  parseStream upTo: (Character value: 31).
formats _ parseStream upTo: (Character value: 30).


self halt.
^ self 

! !

Object subclass: #SDTSTransferDecoder
	instanceVariableNames: 'directoryName catalogDirectory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SDTSTransferDecoder class methodsFor: 'initialization' stamp: 'jrm 6/16/2003 19:37'!
catd
	"Add the definition of Catalog/Directory module to Modules"

	| |
	! !

!SDTSTransferDecoder class methodsFor: 'initialization' stamp: 'jrm 9/5/2009 19:43'!
initialize
	"SDTS Modules Specifications"

	"Comment out for now. I am not sure what this is supposed to do.
	
	ModulesSpecifications _ Dictionary new.

	ModulesSpecifications at: 'Catalog/Directory' put: (ModuleSpecification name:'Module Name' description: 'A unique identifier for this Catalog/Directory Module' type: 'A' domain: 'Alphanum')"! !

Object subclass: #SubfieldSpecification
	instanceVariableNames: 'name description type domain mnemonic'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SDTS-Browser'!

!SubfieldSpecification class methodsFor: 'as yet unclassified' stamp: 'jrm 6/15/2003 20:21'!
name: nameString description: descriptionString type: typeString domain: domainString mnemonic: mnemonicString

	^ super new
		name: nameString description: descriptionString type: typeString domain: domainString mnemonic: mnemonicString! !

!SubfieldSpecification methodsFor: 'as yet unclassified' stamp: 'jrm 6/15/2003 21:00'!
initialize


	! !

!SubfieldSpecification methodsFor: 'as yet unclassified' stamp: 'jrm 6/15/2003 21:07'!
name: nameString description: descriptionString type: typeString domain: domainString mnemonic: mnemonicString

		name _  nameString. 
		description _  descriptionString. 
		type _  typeString. 
		domain _  domainString. 
		mnemonic _  mnemonicString! !
ISO8211LeaderMap initialize!
SDTSModuleDecoder initialize!
SDTSRecordDecoder initialize!
SDTSTransferDecoder initialize!
